@@ -26,14 +26,15 @@ struct AccessToken {
 }
 
 #[derive(Debug)]
-pub struct GoogleAuth {
+pub struct Google {
 	client_id: String,
 	client_secret: String,
 	refresh_token: String,
 	access_token: Option<AccessToken>,
 }
 
-impl GoogleAuth {
+impl Google {
+	#[must_use]
 	pub fn new(client_id: String, client_secret: String, refresh_token: String) -> Self {
 		Self {
 			client_id,
@@ -43,6 +44,7 @@ impl GoogleAuth {
 		}
 	}
 
+	#[allow(clippy::items_after_statements)] // TODO
 	pub async fn generate_refresh_token(
 		client_id: &str,
 		client_secret: &str,
@@ -116,10 +118,11 @@ impl GoogleAuth {
 	}
 
 	pub async fn access_token(&mut self) -> Result<&str> {
+		// FIXME: for some reason the token sometimes expires by itself and should be renewed manually
 		// Update the token if:
 		// we haven't done that yet
 		if self.access_token.is_none()
-			// or if if it has expired
+			// or if if has expired
 			|| self
 				.access_token
 				.as_ref()
