@@ -11,14 +11,14 @@ use serde::{Deserialize, Serialize};
 use crate::auth;
 
 #[derive(Serialize, Deserialize, Debug)]
-pub(crate) struct GoogleAuth {
+pub(crate) struct Google {
 	pub(crate) client_id: String,
 	pub(crate) client_secret: String,
 	pub(crate) refresh_token: String,
 }
 
-impl GoogleAuth {
-	pub(crate) fn parse(self) -> auth::GoogleAuth {
-		auth::GoogleAuth::new(self.client_id, self.client_secret, self.refresh_token)
+impl Google {
+	pub(crate) fn parse(self) -> auth::Google {
+		auth::Google::new(self.client_id, self.client_secret, self.refresh_token)
 	}
 }
