@@ -6,14 +6,15 @@
  * Copyright (C) 2022, Sergey Kasmynin (https://github.com/SergeyKasmy)
  */
 
-use super::Id;
+use crate::entry::Entry;
 
 #[derive(Default, Debug)]
-pub struct ReadFilterNewer {
+pub struct Newer {
+	pub(crate) name: String,
 	pub(crate) last_read_id: Option<String>,
 }
 
-impl ReadFilterNewer {
+impl Newer {
 	// pub fn new(last_read_id: Option<String>) -> Self {
 	// 	Self { last_read_id }
 	// }
@@ -23,7 +24,7 @@ impl ReadFilterNewer {
 	}
 
 	/// Make sure list is sorted newest to oldest
-	pub fn remove_read_from<T: Id>(&self, list: &mut Vec<T>) {
+	pub fn remove_read_from(&self, list: &mut Vec<Entry>) {
 		if let Some(last_read_id) = &self.last_read_id {
 			if let Some(last_read_id_pos) =
 				list.iter().position(|x| x.id() == last_read_id.as_str())
@@ -33,8 +34,8 @@ impl ReadFilterNewer {
 		}
 	}
 
-	/// Check if current_id is unread
-	/// Make sure id_list is sorted newest to oldest
+	/// Check if `current_id` is unread
+	/// Make sure `id_list` is sorted newest to oldest
 	pub fn is_unread(&self, current_id: &str, id_list: &[&str]) -> bool {
 		if let Some(last_read_id) = &self.last_read_id {
 			if current_id == last_read_id {
@@ -64,6 +65,6 @@ impl ReadFilterNewer {
 	}
 
 	pub fn mark_as_read(&mut self, id: &str) {
-		self.last_read_id = Some(id.to_owned())
+		self.last_read_id = Some(id.to_owned());
 	}
 }
