@@ -7,13 +7,12 @@
  */
 
 pub mod config;
-mod data;
-mod read_filter;
+pub mod data;
+pub mod read_filter;
 
 pub use self::data::{
 	generate_google_oauth2, generate_google_password, generate_telegram, generate_twitter_auth,
 	google_oauth2, google_password, telegram, twitter,
 };
-pub use self::read_filter::{read_filter, save_read_filter};
 
 const PREFIX: &str = "fetcher";
